==> xl-repository-api-2019.1.1-sources.jar: com/xebialabs/deployit/repository/RepositoryService.java <==
package com.xebialabs.deployit.repository;

import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.Collection;
import java.util.List;

/**
 * CRUDL for RepositoryEntity and things extending...
 */
public interface RepositoryService {

    boolean exists(String id);

    <T extends ConfigurationItem> T read(String id);

    <T extends ConfigurationItem> T read(String id, int depth);

    <T extends ConfigurationItem> T read(String id, WorkDir workDir);

    <T extends ConfigurationItem> T read(String id, boolean useCache);

    <T extends ConfigurationItem> T read(String id, WorkDir workDir, boolean useCache);

    <T extends ConfigurationItem> T read(String id, int depth, WorkDir workDir, boolean useCache);

    <T extends ConfigurationItem> List<T> read(List<String> ids, int depth, boolean useCache);

    List<ConfigurationItemData> list(SearchParameters criteria);

    long count(SearchParameters criteria);

    <T extends ConfigurationItem> List<T> listEntities(SearchParameters parameters);

    <T extends ConfigurationItem> List<T> listEntities(SearchParameters parameters, int depth, boolean useCache);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void create(T... entity);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void update(T... entity);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void createOrUpdate(T... entity);

    <T extends ConfigurationItem> void move(String id, String newId);

    <T extends ConfigurationItem> void copy(String id, String newId);

    void rename(String id, String newName);

    void delete(String... id);

    void execute(ChangeSet changeset);

    void execute(ChangeSet changeset, ProgressLogger progressLogger);

    void execute(ChangeSet changeset, ProgressLogger progressLogger, String taskId);

    void checkReferentialIntegrity(ChangeSet changeset) throws ItemInUseException, ItemAlreadyExistsException;

    default <T extends ConfigurationItem> void createCollection(Collection<T> entities) {
        create(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default <T extends ConfigurationItem> void createOrUpdateCollection(Collection<T> entities) {
        createOrUpdate(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default <T extends ConfigurationItem> void updateCollection(Collection<T> entities) {
        update(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default void deleteCollection(Collection<String> entities) {
        delete(entities.toArray(new String[entities.size()]));
    }

}

==> xl-repository-api-2019.1.2-sources.jar: com/xebialabs/deployit/repository/RepositoryService.java <==
package com.xebialabs.deployit.repository;

import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.Collection;
import java.util.List;

/**
 * CRUDL for RepositoryEntity and things extending...
 */
public interface RepositoryService {

    boolean exists(String id);

    <T extends ConfigurationItem> T read(String id);

    <T extends ConfigurationItem> T read(String id, int depth);

    <T extends ConfigurationItem> T read(String id, WorkDir workDir);

    <T extends ConfigurationItem> T read(String id, boolean useCache);

    <T extends ConfigurationItem> T read(String id, WorkDir workDir, boolean useCache);

    <T extends ConfigurationItem> T read(String id, int depth, WorkDir workDir, boolean useCache);

    <T extends ConfigurationItem> List<T> read(List<String> ids, int depth, boolean useCache);

    List<ConfigurationItemData> list(SearchParameters criteria);

    long count(SearchParameters criteria);

    <T extends ConfigurationItem> List<T> listEntities(SearchParameters parameters);

    <T extends ConfigurationItem> List<T> listEntities(SearchParameters parameters, int depth, boolean useCache);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void create(T... entity);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void update(T... entity);

    @SuppressWarnings("unchecked")
    <T extends ConfigurationItem> void createOrUpdate(T... entity);

    <T extends ConfigurationItem> void move(String id, String newId);

    <T extends ConfigurationItem> void copy(String id, String newId);

    void rename(String id, String newName);

    void delete(String... id);

    void execute(ChangeSet changeset);

    void execute(ChangeSet changeset, String taskId);

    void execute(ChangeSet changeset, ProgressLogger progressLogger, String taskId);

    void checkReferentialIntegrity(ChangeSet changeset) throws ItemInUseException, ItemAlreadyExistsException;

    default <T extends ConfigurationItem> void createCollection(Collection<T> entities) {
        create(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default <T extends ConfigurationItem> void createOrUpdateCollection(Collection<T> entities) {
        createOrUpdate(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default <T extends ConfigurationItem> void updateCollection(Collection<T> entities) {
        update(entities.toArray(new ConfigurationItem[entities.size()]));
    }

    default void deleteCollection(Collection<String> entities) {
        delete(entities.toArray(new String[entities.size()]));
    }

}
